import type { createFetcher } from '../network/index.js';
import type { DBRecord, DBRecordTarget, Relation, RelationDetachOptions, RelationOptions } from '../sdk/record.js';
import type { Transaction } from '../sdk/transaction.js';
import type { Property, PropertyValuesData, SearchQuery, Schema, MaybeArray } from '../types/index.js';
import type { ApiResponse } from './types.js';
import { DBRecordsBatchDraft, DBRecordDraft } from '../sdk/record.js';
export declare const createApi: (fetcher: ReturnType<typeof createFetcher>) => {
    labels: {
        find<S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string): Promise<ApiResponse<Record<string, number>>>;
    };
    properties: {
        delete: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<Property>>;
        find: <S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<Property[]>>;
        findById: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<Property>>;
        values: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<Property & PropertyValuesData>>;
    };
    records: {
        attach: (source: DBRecordTarget, idOrIds: MaybeArray<string>, options?: RelationOptions, transaction?: Transaction | string) => Promise<ApiResponse<{
            message: string;
        }>>;
        create<S extends Schema = any>(data: DBRecordDraft | S, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S> | undefined>>;
        createMany<S extends Schema = any>(data: DBRecordsBatchDraft | S[], transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>[]>>;
        delete<S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string): Promise<ApiResponse<{
            message: string;
        }>>;
        deleteById(idOrIds: MaybeArray<string>, transaction?: Transaction | string): Promise<ApiResponse<{
            message: string;
        }>>;
        detach: (source: DBRecordTarget, idOrIds: MaybeArray<string>, options?: RelationDetachOptions, transaction?: Transaction | string) => Promise<ApiResponse<{
            message: string;
        }>>;
        export<S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string): Promise<ApiResponse<{
            dateTime: string;
            fileContent: string;
        }>>;
        find<S extends Schema = any>(params?: {
            id?: string;
            searchParams: SearchQuery<S>;
        }, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>[]>>;
        findById<S extends Schema = any>(idOrIds: MaybeArray<string>, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>[]>> | Promise<ApiResponse<DBRecord<S>>>;
        findOne<S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>>>;
        findUniq<S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>>>;
        properties(target: string, transaction?: Transaction | string): Promise<ApiResponse<Property[]>>;
        relations: (target: DBRecordTarget, transaction?: Transaction | string) => Promise<ApiResponse<Relation[]>>;
        set<S extends Schema = any>(target: DBRecordTarget, data: DBRecordDraft | S, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>>>;
        update<S extends Schema = any>(target: DBRecordTarget, data: DBRecordDraft | S, transaction?: Transaction | string): Promise<ApiResponse<DBRecord<S>>>;
    };
    relations: {
        find: <S extends Schema = any>(searchParams: SearchQuery<S>, pagination?: Pick<SearchQuery, "limit" | "skip">, transaction?: Transaction | string) => Promise<ApiResponse<Relation[]>>;
    };
    tx: {
        begin(config?: Partial<{
            ttl: number;
        }>): Promise<ApiResponse<{
            id: string;
        }>>;
        commit(id: string): Promise<ApiResponse<{
            message: string;
        }>>;
        get(id: string): Promise<ApiResponse<{
            id: string;
        }>>;
        rollback(id: string): Promise<ApiResponse<{
            message: string;
        }>>;
    };
};
